summaryrefslogtreecommitdiff
path: root/distro
diff options
context:
space:
mode:
authorLudovic Courtès <ludo@gnu.org>2012-12-21 23:52:48 +0100
committerLudovic Courtès <ludo@gnu.org>2012-12-21 23:52:48 +0100
commit380d5decfcd3a25c11dfa7e78e2197af98a35307 (patch)
treebf9f63d190f7ba849430eb440664a0d30ae9d382 /distro
parentc089511288820cfb3efc5295e572be24aa83f068 (diff)
downloadguix-patches-380d5decfcd3a25c11dfa7e78e2197af98a35307.tar
guix-patches-380d5decfcd3a25c11dfa7e78e2197af98a35307.tar.gz
distro: attr: Fix references to /bin/sh.
* distro/packages/attr.scm (attr): Add `patch-makefile-SHELL'. Patch `test/run' in `check' phase.
Diffstat (limited to 'distro')
-rw-r--r--distro/packages/attr.scm43
1 files changed, 27 insertions, 16 deletions
diff --git a/distro/packages/attr.scm b/distro/packages/attr.scm
index 38c75fc2ae..ad2cd3987a 100644
--- a/distro/packages/attr.scm
+++ b/distro/packages/attr.scm
@@ -41,23 +41,34 @@
(build-system gnu-build-system)
(arguments
`(#:phases
- (alist-replace 'install
- (lambda _
- (zero? (system* "make"
- "install"
- "install-lib"
- "install-dev")))
- (alist-replace 'check
- (lambda _
- (for-each patch-shebang
- (find-files "test" ".*"))
- (system* "make" "tests" "-C" "test")
+ (alist-cons-after
+ 'configure 'patch-makefile-SHELL
+ (lambda _
+ (patch-makefile-SHELL "include/buildmacros"))
+ (alist-replace
+ 'install
+ (lambda _
+ (zero? (system* "make"
+ "install"
+ "install-lib"
+ "install-dev")))
+ (alist-replace
+ 'check
+ (lambda _
+ ;; Use the right shell.
+ (let ((bash (search-path (search-path-as-string->list
+ (getenv "PATH"))
+ "bash")))
+ (substitute* "test/run"
+ (("/bin/sh")
+ (string-append bash "/bin/bash"))))
- ;; XXX: Ignore the test result since
- ;; this is dependent on the underlying
- ;; file system.
- #t)
- %standard-phases))))
+ (system* "make" "tests" "-C" "test")
+
+ ;; XXX: Ignore the test result since this is dependent on the
+ ;; underlying file system.
+ #t)
+ %standard-phases)))))
(inputs `(("perl" ,perl)
("gettext" ,guix:gettext)))
(home-page